	mrs	x0, mpambw0_el1
	msr	mpambw0_el1, x0
	mrs	x0, mpambw1_el1
	msr	mpambw1_el1, x0
	mrs	x0, mpambw1_el12
	msr	mpambw1_el12, x0
	mrs	x0, mpambw2_el2
	msr	mpambw2_el2, x0
	mrs	x0, mpambw3_el3
	msr	mpambw3_el3, x0
	mrs	x0, mpambwcap_el2
	msr	mpambwcap_el2, x0
	mrs	x0, mpambwidr_el1
