.* Assembler messages:
.*:5: Error: all tmm registers must be distinct for `tmmultf32ps'
.*:6: Error: all tmm registers must be distinct for `tmmultf32ps'
.*:7: Error: all tmm registers must be distinct for `tmmultf32ps'
.*:8: Error: all tmm registers must be distinct for `ttmmultf32ps'
.*:9: Error: all tmm registers must be distinct for `ttmmultf32ps'
.*:10: Error: all tmm registers must be distinct for `ttmmultf32ps'
