ARCH=avr:102
MACHINE=
SCRIPT_NAME=avr
OUTPUT_FORMAT="elf32-avr"
MAXPAGESIZE=1
EMBEDDED=yes
TEMPLATE_NAME=elf

TEXT_LENGTH=1024K
DATA_ORIGIN=0x802000
DATA_LENGTH=0xffa0
EXTRA_EM_FILE=avrelf

FUSE_NAME=fuse

EEPROM_LENGTH=64K
FUSE_LENGTH=1K
LOCK_LENGTH=1K
SIGNATURE_LENGTH=1K
USER_SIGNATURE_LENGTH=1K

MAYBE_FLMAP=1

# Above is a copy of the contents of avrxmega2.sh

HAVE_FLMAP=1
RODATA_VMA=0xa00000
RODATA_LENGTH=32K
RODATA_LDS_OFFSET=0x8000
RODATA_FLASH_START=32K
FLMAP_MASK=0x1
