[^:]*: Assembler messages:
.*: Error: selected processor does not support `fmmla z0.h,z0.b,z0.b'
.*: Error: selected processor does not support `fmmla z0.h,z0.b,z31.b'
.*: Error: selected processor does not support `fmmla z0.h,z31.b,z0.b'
.*: Error: selected processor does not support `fmmla z0.h,z31.b,z31.b'
.*: Error: selected processor does not support `fmmla z31.h,z0.b,z0.b'
.*: Error: selected processor does not support `fmmla z31.h,z0.b,z31.b'
.*: Error: selected processor does not support `fmmla z31.h,z31.b,z0.b'
.*: Error: selected processor does not support `fmmla z31.h,z31.b,z31.b'
.*: Error: selected processor does not support `movprfx z0,z15'
.*: Error: selected processor does not support `fmmla z0.h,z1.b,z1.b'
.*: Error: selected processor does not support `movprfx z0,z15'
.*: Error: selected processor does not support `fmmla z0.h,z1.b,z31.b'
.*: Error: selected processor does not support `movprfx z0,z15'
.*: Error: selected processor does not support `fmmla z0.h,z31.b,z1.b'
.*: Error: selected processor does not support `movprfx z0,z15'
.*: Error: selected processor does not support `fmmla z0.h,z31.b,z31.b'
.*: Error: selected processor does not support `movprfx z31,z15'
.*: Error: selected processor does not support `fmmla z31.h,z0.b,z0.b'
.*: Error: selected processor does not support `movprfx z31,z15'
.*: Error: selected processor does not support `fmmla z31.h,z0.b,z30.b'
.*: Error: selected processor does not support `movprfx z31,z15'
.*: Error: selected processor does not support `fmmla z31.h,z30.b,z0.b'
.*: Error: selected processor does not support `movprfx z31,z15'
.*: Error: selected processor does not support `fmmla z31.h,z30.b,z30.b'
